from prettyqt.qt import QtCore


class RandomGenerator(QtCore.QRandomGenerator):
    pass
